change log for rtems (2010-11-25)

rtems-vc at rtems.org rtems-vc at rtems.org
Thu Nov 25 14:10:36 UTC 2010


 *sh*:
2010-11-25	Sebastian Huber <sebastian.huber at embedded-brains.de>

	* sapi/include/confdefs.h, score/include/rtems/score/scheduler.h,
	score/inline/rtems/score/scheduler.inl,
	score/inline/rtems/score/schedulerpriority.inl,
	score/src/schedulerpriority.c,
	score/src/schedulerprioritythreadschedulerallocate.c,
	score/src/schedulerprioritythreadschedulerfree.c,
	score/src/schedulerprioritythreadschedulerupdate.c,
	score/src/schedulerpriorityyield.c: Added attribute unused.  Renamed
	types and fields to follow the Score naming conventions.

M 1.2659  cpukit/ChangeLog
M  1.152  cpukit/sapi/include/confdefs.h
M    1.3  cpukit/score/include/rtems/score/scheduler.h
M    1.2  cpukit/score/inline/rtems/score/scheduler.inl
M    1.3  cpukit/score/inline/rtems/score/schedulerpriority.inl
M    1.2  cpukit/score/src/schedulerpriority.c
M    1.2  cpukit/score/src/schedulerprioritythreadschedulerallocate.c
M    1.2  cpukit/score/src/schedulerprioritythreadschedulerfree.c
M    1.2  cpukit/score/src/schedulerprioritythreadschedulerupdate.c
M    1.3  cpukit/score/src/schedulerpriorityyield.c

diff -u rtems/cpukit/ChangeLog:1.2658 rtems/cpukit/ChangeLog:1.2659
--- rtems/cpukit/ChangeLog:1.2658	Thu Nov 25 06:42:50 2010
+++ rtems/cpukit/ChangeLog	Thu Nov 25 07:24:25 2010
@@ -1,5 +1,17 @@
 2010-11-25	Sebastian Huber <sebastian.huber at embedded-brains.de>
 
+	* sapi/include/confdefs.h, score/include/rtems/score/scheduler.h,
+	score/inline/rtems/score/scheduler.inl,
+	score/inline/rtems/score/schedulerpriority.inl,
+	score/src/schedulerpriority.c,
+	score/src/schedulerprioritythreadschedulerallocate.c,
+	score/src/schedulerprioritythreadschedulerfree.c,
+	score/src/schedulerprioritythreadschedulerupdate.c,
+	score/src/schedulerpriorityyield.c: Added attribute unused.  Renamed
+	types and fields to follow the Score naming conventions.
+
+2010-11-25	Sebastian Huber <sebastian.huber at embedded-brains.de>
+
 	* score/include/rtems/score/scheduler.h,
 	score/include/rtems/score/schedulerpriority.h: Whitespace removal.
 	Moved C++ extern directive.

diff -u rtems/cpukit/sapi/include/confdefs.h:1.151 rtems/cpukit/sapi/include/confdefs.h:1.152
--- rtems/cpukit/sapi/include/confdefs.h:1.151	Wed Nov 24 09:51:27 2010
+++ rtems/cpukit/sapi/include/confdefs.h	Thu Nov 25 07:24:25 2010
@@ -617,7 +617,7 @@
 
 #ifdef CONFIGURE_INIT
   /* the table of available schedulers. */
-  const Scheduler_Table_t _Scheduler_Table[] = {
+  const Scheduler_Table_entry _Scheduler_Table[] = {
     #if defined(CONFIGURE_SCHEDULER_USER) && \
         defined(CONFIGURE_SCHEDULER_ENTRY_USER)
       CONFIGURE_SCHEDULER_ENTRY_USER,

diff -u rtems/cpukit/score/inline/rtems/score/scheduler.inl:1.1 rtems/cpukit/score/inline/rtems/score/scheduler.inl:1.2
--- rtems/cpukit/score/inline/rtems/score/scheduler.inl:1.1	Wed Nov 24 09:51:28 2010
+++ rtems/cpukit/score/inline/rtems/score/scheduler.inl	Thu Nov 25 07:24:25 2010
@@ -51,7 +51,7 @@
     Scheduler_Control *the_scheduler 
 )
 {
-  the_scheduler->operations.schedule( the_scheduler );
+  the_scheduler->Operations.schedule( the_scheduler );
 }
 
 /** @brief _Scheduler_Yield
@@ -63,7 +63,7 @@
  */
 RTEMS_INLINE_ROUTINE void _Scheduler_Yield( void )
 {
-  _Scheduler.operations.yield( &_Scheduler );
+  _Scheduler.Operations.yield( &_Scheduler );
 }
 
 /** @brief _Scheduler_Block
@@ -78,7 +78,7 @@
     Thread_Control    *the_thread 
 )
 {
-  the_scheduler->operations.block( the_scheduler, the_thread );
+  the_scheduler->Operations.block( the_scheduler, the_thread );
 }
 
 /** @brief _Scheduler_Unblock
@@ -93,7 +93,7 @@
     Thread_Control    *the_thread 
 )
 {
-  the_scheduler->operations.unblock( the_scheduler, the_thread );
+  the_scheduler->Operations.unblock( the_scheduler, the_thread );
 }
 
 /** @brief _Scheduler_Thread_scheduler_allocate
@@ -106,7 +106,7 @@
 )
 {
   return 
-    the_scheduler->operations.scheduler_allocate( the_scheduler, the_thread );
+    the_scheduler->Operations.scheduler_allocate( the_scheduler, the_thread );
 }
 
 /** @brief _Scheduler_Thread_scheduler_free
@@ -118,7 +118,7 @@
   Thread_Control    *the_thread
 )
 {
-  return the_scheduler->operations.scheduler_free( the_scheduler, the_thread );
+  return the_scheduler->Operations.scheduler_free( the_scheduler, the_thread );
 }
 
 /** @brief _Scheduler_Thread_scheduler_update
@@ -130,7 +130,7 @@
   Thread_Control    *the_thread
 )
 {
-  the_scheduler->operations.scheduler_update( the_scheduler, the_thread );
+  the_scheduler->Operations.scheduler_update( the_scheduler, the_thread );
 }
 
 /**@}*/

diff -u rtems/cpukit/score/inline/rtems/score/schedulerpriority.inl:1.2 rtems/cpukit/score/inline/rtems/score/schedulerpriority.inl:1.3
--- rtems/cpukit/score/inline/rtems/score/schedulerpriority.inl:1.2	Thu Nov 25 03:27:06 2010
+++ rtems/cpukit/score/inline/rtems/score/schedulerpriority.inl	Thu Nov 25 07:24:26 2010
@@ -34,17 +34,17 @@
 RTEMS_INLINE_ROUTINE void _Scheduler_priority_Ready_queue_initialize(
   Scheduler_Control         *the_scheduler
 ) {
-  uint32_t index;
+  size_t index;
 
   /* allocate ready queue structures */
-  the_scheduler->ready_queues.Priority = (Chain_Control *) 
+  the_scheduler->Ready_queues.priority = (Chain_Control *) 
     _Workspace_Allocate_or_fatal_error(
-      (PRIORITY_MAXIMUM + 1) * sizeof(Chain_Control)
+      ((size_t) PRIORITY_MAXIMUM + 1) * sizeof(Chain_Control)
     );
 
   /* initialize ready queue structures */
   for( index=0; index <= PRIORITY_MAXIMUM; index++)
-    _Chain_Initialize_empty( &the_scheduler->ready_queues.Priority[index] );
+    _Chain_Initialize_empty( &the_scheduler->Ready_queues.priority[index] );
 }
 
 /* 
@@ -194,7 +194,7 @@
 )
 {
   _Thread_Heir = _Scheduler_priority_Ready_queue_first(
-      the_scheduler->ready_queues.Priority
+      the_scheduler->Ready_queues.priority
   );
 }
 
@@ -250,7 +250,7 @@
  */
 
 RTEMS_INLINE_ROUTINE void _Scheduler_priority_Unblock_body (
-  Scheduler_Control       *the_scheduler,
+  Scheduler_Control       *the_scheduler __attribute__((unused)),
   Thread_Control          *the_thread
 )
 {

diff -u rtems/cpukit/score/src/schedulerpriority.c:1.1 rtems/cpukit/score/src/schedulerpriority.c:1.2
--- rtems/cpukit/score/src/schedulerpriority.c:1.1	Wed Nov 24 09:51:28 2010
+++ rtems/cpukit/score/src/schedulerpriority.c	Thu Nov 25 07:24:26 2010
@@ -50,15 +50,15 @@
    * for the scheduler.  Every scheduler implementation provides its own
    * scheduler operations table.
    */
-  the_scheduler->operations.schedule           = &_Scheduler_priority_Schedule;
-  the_scheduler->operations.yield              = &_Scheduler_priority_Yield;
-  the_scheduler->operations.block              = &_Scheduler_priority_Block;
-  the_scheduler->operations.unblock            = &_Scheduler_priority_Unblock;
-  the_scheduler->operations.scheduler_allocate = 
+  the_scheduler->Operations.schedule           = &_Scheduler_priority_Schedule;
+  the_scheduler->Operations.yield              = &_Scheduler_priority_Yield;
+  the_scheduler->Operations.block              = &_Scheduler_priority_Block;
+  the_scheduler->Operations.unblock            = &_Scheduler_priority_Unblock;
+  the_scheduler->Operations.scheduler_allocate = 
       &_Scheduler_priority_Thread_scheduler_allocate;
-  the_scheduler->operations.scheduler_free     = 
+  the_scheduler->Operations.scheduler_free     = 
       &_Scheduler_priority_Thread_scheduler_free;
-  the_scheduler->operations.scheduler_update   = 
+  the_scheduler->Operations.scheduler_update   = 
       &_Scheduler_priority_Thread_scheduler_update;
 
   _Scheduler_priority_Ready_queue_initialize( the_scheduler );

diff -u rtems/cpukit/score/src/schedulerprioritythreadschedulerallocate.c:1.1 rtems/cpukit/score/src/schedulerprioritythreadschedulerallocate.c:1.2
--- rtems/cpukit/score/src/schedulerprioritythreadschedulerallocate.c:1.1	Wed Nov 24 09:51:28 2010
+++ rtems/cpukit/score/src/schedulerprioritythreadschedulerallocate.c	Thu Nov 25 07:24:26 2010
@@ -39,7 +39,7 @@
  */
 
 void* _Scheduler_priority_Thread_scheduler_allocate (
-  Scheduler_Control     *the_scheduler,
+  Scheduler_Control     *the_scheduler __attribute__((unused)),
   Thread_Control        *the_thread
 )
 {

diff -u rtems/cpukit/score/src/schedulerprioritythreadschedulerfree.c:1.1 rtems/cpukit/score/src/schedulerprioritythreadschedulerfree.c:1.2
--- rtems/cpukit/score/src/schedulerprioritythreadschedulerfree.c:1.1	Wed Nov 24 09:51:28 2010
+++ rtems/cpukit/score/src/schedulerprioritythreadschedulerfree.c	Thu Nov 25 07:24:26 2010
@@ -38,7 +38,7 @@
  */
 
 void _Scheduler_priority_Thread_scheduler_free (
-    Scheduler_Control *the_scheduler,
+    Scheduler_Control *the_scheduler __attribute__((unused)),
     Thread_Control    *the_thread
 )
 {

diff -u rtems/cpukit/score/src/schedulerprioritythreadschedulerupdate.c:1.1 rtems/cpukit/score/src/schedulerprioritythreadschedulerupdate.c:1.2
--- rtems/cpukit/score/src/schedulerprioritythreadschedulerupdate.c:1.1	Wed Nov 24 09:51:28 2010
+++ rtems/cpukit/score/src/schedulerprioritythreadschedulerupdate.c	Thu Nov 25 07:24:26 2010
@@ -43,7 +43,7 @@
     Thread_Control    *the_thread
 )
 {
-  Chain_Control *rq = the_scheduler->ready_queues.Priority;
+  Chain_Control *rq = the_scheduler->Ready_queues.priority;
   the_thread->scheduler.priority->ready_chain = &rq[
     the_thread->current_priority 
   ];

diff -u rtems/cpukit/score/src/schedulerpriorityyield.c:1.2 rtems/cpukit/score/src/schedulerpriorityyield.c:1.3
--- rtems/cpukit/score/src/schedulerpriorityyield.c:1.2	Thu Nov 25 03:27:06 2010
+++ rtems/cpukit/score/src/schedulerpriorityyield.c	Thu Nov 25 07:24:26 2010
@@ -50,7 +50,7 @@
  */
 
 void _Scheduler_priority_Yield( 
-    Scheduler_Control   *the_scheduler
+    Scheduler_Control   *the_scheduler __attribute__((unused))
 )
 {
   ISR_Level       level;


 *sh*:
2010-11-25	Sebastian Huber <sebastian.huber at embedded-brains.de>

	* tm26/task1.c, tm27/task1.c: Update for API changes.

M   1.92  testsuites/tmtests/ChangeLog
M   1.34  testsuites/tmtests/tm26/task1.c
M   1.31  testsuites/tmtests/tm27/task1.c

diff -u rtems/testsuites/tmtests/ChangeLog:1.91 rtems/testsuites/tmtests/ChangeLog:1.92
--- rtems/testsuites/tmtests/ChangeLog:1.91	Wed Nov 24 10:06:37 2010
+++ rtems/testsuites/tmtests/ChangeLog	Thu Nov 25 07:26:45 2010
@@ -1,3 +1,7 @@
+2010-11-25	Sebastian Huber <sebastian.huber at embedded-brains.de>
+
+	* tm26/task1.c, tm27/task1.c: Update for API changes.
+
 2010-11-24	Gedare Bloom <giddyup44 at yahoo.com>
 
 	PR 1647/cpukit

diff -u rtems/testsuites/tmtests/tm26/task1.c:1.33 rtems/testsuites/tmtests/tm26/task1.c:1.34
--- rtems/testsuites/tmtests/tm26/task1.c:1.33	Wed Nov 24 10:06:37 2010
+++ rtems/testsuites/tmtests/tm26/task1.c	Thu Nov 25 07:26:45 2010
@@ -243,7 +243,7 @@
 
   _Thread_Executing =
         (Thread_Control *) 
-        _Chain_First(&_Scheduler.ready_queues.Priority[LOW_PRIORITY]);
+        _Chain_First(&_Scheduler.Ready_queues.priority[LOW_PRIORITY]);
 
   /* do not force context switch */
 
@@ -281,7 +281,7 @@
 
   _Thread_Executing =
         (Thread_Control *) 
-        _Chain_First(&_Scheduler.ready_queues.Priority[FP1_PRIORITY]);
+        _Chain_First(&_Scheduler.Ready_queues.priority[FP1_PRIORITY]);
 
   /* do not force context switch */
 
@@ -309,7 +309,7 @@
 
   _Thread_Executing =
         (Thread_Control *) 
-        _Chain_First(&_Scheduler.ready_queues.Priority[FP2_PRIORITY]);
+        _Chain_First(&_Scheduler.Ready_queues.priority[FP2_PRIORITY]);
 
   /* do not force context switch */
 
@@ -333,7 +333,7 @@
 
   _Thread_Executing =
        (Thread_Control *)
-       _Chain_First(&_Scheduler.ready_queues.Priority[FP2_PRIORITY]);
+       _Chain_First(&_Scheduler.Ready_queues.priority[FP2_PRIORITY]);
 
   /* do not force context switch */
 
@@ -363,7 +363,7 @@
 
   _Thread_Executing =
        (Thread_Control *)
-       _Chain_First(&_Scheduler.ready_queues.Priority[FP1_PRIORITY]);
+       _Chain_First(&_Scheduler.Ready_queues.priority[FP1_PRIORITY]);
 
   FP_LOAD( 1.0 );
 

diff -u rtems/testsuites/tmtests/tm27/task1.c:1.30 rtems/testsuites/tmtests/tm27/task1.c:1.31
--- rtems/testsuites/tmtests/tm27/task1.c:1.30	Wed Nov 24 10:06:37 2010
+++ rtems/testsuites/tmtests/tm27/task1.c	Thu Nov 25 07:26:45 2010
@@ -171,7 +171,7 @@
   _Thread_Dispatch_disable_level = 0;
 
   _Thread_Heir = (rtems_tcb *) 
-        _Chain_Last(&_Scheduler.ready_queues.Priority[LOW_PRIORITY]);
+        _Chain_Last(&_Scheduler.Ready_queues.priority[LOW_PRIORITY]);
 
   _Thread_Dispatch_necessary = 1;
 
@@ -229,7 +229,7 @@
   _Thread_Dispatch_disable_level = 0;
 
   _Thread_Heir = (rtems_tcb *)
-      _Chain_First(&_Scheduler.ready_queues.Priority[LOW_PRIORITY]);
+      _Chain_First(&_Scheduler.Ready_queues.priority[LOW_PRIORITY]);
 
   _Thread_Dispatch_necessary = 1;
 



diff -u rtems/cpukit/score/include/rtems/score/scheduler.h:1.2 rtems/cpukit/score/include/rtems/score/scheduler.h:1.3
--- rtems/cpukit/score/include/rtems/score/scheduler.h:1.2	Thu Nov 25 06:42:50 2010
+++ rtems/cpukit/score/include/rtems/score/scheduler.h	Thu Nov 25 07:24:25 2010
@@ -38,7 +38,7 @@
 /*
  * These defines are used to set the scheduler_policy value. The values
  * must correspond directly with the order of the fields in the scheduler
  * table (Scheduler_Table_t), because the Configuration.scheduler_policy
  * field is used to index the scheduler table.
  */
 #define _Scheduler_USER     (0)
@@ -47,16 +47,15 @@
 typedef struct Scheduler_Control_struct Scheduler_Control;
 
 /*
  * The Scheduler_Table_t type defines the scheduler initialization table,
  * which is set up by confdefs.h based on the user's choice of scheduler
  * policy.
  */
 typedef struct {
   void ( *scheduler_init )( Scheduler_Control * );
-} Scheduler_Table_t;
+} Scheduler_Table_entry;
 
 /* instantiated and initialized in confdefs.h */
-extern const Scheduler_Table_t          _Scheduler_Table[];
+extern const Scheduler_Table_entry _Scheduler_Table[];
 
 /**
  * The following Scheduler_Per_thread_xxx structures are used to
@@ -119,12 +118,12 @@
      * This is the set of lists (an array of Chain_Control) for
      * priority scheduling.
      */
-    Chain_Control            *Priority;
+    Chain_Control            *priority;
 
-  } ready_queues;
+  } Ready_queues;
 
   /** The jump table for scheduler-specific functions */
-  Scheduler_Operations                  operations;
+  Scheduler_Operations                  Operations;
 };
 
 /**
@@ -38,7 +38,7 @@
  * These defines are used to set the scheduler_policy value. The values
  * must correspond directly with the order of the fields in the scheduler
- * table (Scheduler_Table_t), because the Configuration.scheduler_policy
+ * table (Scheduler_Table_entry), because the Configuration.scheduler_policy
  * field is used to index the scheduler table.
  */
@@ -47,16 +47,15 @@
 
 /*
- * The Scheduler_Table_t type defines the scheduler initialization table,
- * which is set up by confdefs.h based on the user's choice of scheduler
- * policy.
+ * This type defines the scheduler initialization table entry, which is set up
+ * by confdefs.h based on the user's choice of scheduler policy.
  */
 typedef struct {

--

Generated by Deluxe Loginfo [http://www.codewiz.org/projects/index.html#loginfo] 2.122 by Bernardo Innocenti <bernie at develer.com>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.rtems.org/pipermail/vc/attachments/20101125/76bd877d/attachment.html>


More information about the vc mailing list